SqrtHyperBuffer

Struct SqrtHyperBuffer 

pub struct SqrtHyperBuffer {
    pub low: DeviceBuffer<EF>,
    pub high: DeviceBuffer<EF>,
    pub low_capacity: usize,
    pub size: usize,
}
Square-root decomposition of hypercube equality buffer for memory optimization.

Instead of storing a single buffer of size 2^n, we store two buffers of size 2^(n/2), reducing memory usage from O(2^n) to O(2*2^(n/2)). The full value at index i is computed on-the-fly as: low[i % low_cap] * high[i / low_cap]

Fields

low: DeviceBuffer<EF>high: DeviceBuffer<EF>low_capacity: usizesize: usize

Implementations

Source

impl SqrtHyperBuffer

pub fn from_xi( xi: &[EF], device_ctx: &GpuDeviceCtx, ) -> Result<Self, KernelError>

Build a buffer from xi. Note that last elements of xi correspond to the lowest index bits.

pub fn fold_columns( &mut self, r: EF, device_ctx: &GpuDeviceCtx, ) -> Result<(), CudaError>